@@ -7,38 +7,36 @@
     - https://docs.pytest.org/en/stable/writing_plugins.html
 """
 import pytest
-from senor_octopus.cli import CaseConfigParser
+import yaml
 from senor_octopus.graph import build_dag
 
 
 config_content = """
-[random]
-plugin = source.random
-flow = -> check, normal
-schedule = * * * * *
+random:
+  plugin: source.random
+  flow: -> check, normal
+  schedule: "* * * * *"
 
-[check]
-plugin = filter.jsonpath
-flow = random -> high
-filter = $.events[?(@.value>0.5)]
+check:
+  plugin: filter.jsonpath
+  flow: random -> high
+  filter: $.events[?(@.value>0.5)]
 
-[normal]
-plugin = sink.log
-flow = random ->
+normal:
+  plugin: sink.log
+  flow: random ->
 
-[high]
-plugin = sink.log
-flow = check ->
-throttle = 5 minutes
-level = warning
+high:
+  plugin: sink.log
+  flow: check ->
+  throttle: 5 minutes
+  level: warning
 """
 
 
 @pytest.fixture
 def mock_config():
-    config = CaseConfigParser()
-    config.read_string(config_content)
-    yield config
+    yield yaml.load(config_content)
 
 
 @pytest.fixture
