@@ -1,4 +1,3 @@
-import os
 import random
 
 import pytest
@@ -7,18 +6,11 @@ from senor_octopus.sources.rand import rand
 
 
 @pytest.mark.asyncio
-async def test_pushover(mocker, httpx_mock) -> None:
-    mocker.patch.dict(
-        os.environ,
-        {
-            "PUSHOVER_APP_TOKEN": "XXX",
-            "PUSHOVER_USER_TOKEN": "alice",
-        },
-    )
+async def test_pushover(httpx_mock) -> None:
     httpx_mock.add_response()
     random.seed(42)
 
-    await pushover(rand(2))
+    await pushover(rand(2), "XXX", "alice")
     requests = httpx_mock.get_requests()
     assert len(requests) == 2
     assert (
@@ -28,15 +20,8 @@ async def test_pushover(mocker, httpx_mock) -> None:
 
 
 @pytest.mark.asyncio
-async def test_pushover_empty_stream(mocker, httpx_mock) -> None:
-    mocker.patch.dict(
-        os.environ,
-        {
-            "PUSHOVER_APP_TOKEN": "XXX",
-            "PUSHOVER_USER_TOKEN": "alice",
-        },
-    )
+async def test_pushover_empty_stream(httpx_mock) -> None:
     random.seed(42)
 
-    await pushover(rand(0))
+    await pushover(rand(0), "XXX", "alice")
     assert not httpx_mock.get_request()
